@@ -67,11 +67,35 @@ class CreateAcceleratorRequest(RpcRequest):
 
 	def set_ResourceGroupId(self, ResourceGroupId):  # String
 		self.add_query_param('ResourceGroupId', ResourceGroupId)
+	def get_Tags(self): # RepeatList
+		return self.get_query_params().get('Tag')
+
+	def set_Tags(self, Tag):  # RepeatList
+		for depth1 in range(len(Tag)):
+			if Tag[depth1].get('Key') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tag[depth1].get('Key'))
+			if Tag[depth1].get('Value') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tag[depth1].get('Value'))
+	def get_InstanceChargeType(self): # String
+		return self.get_query_params().get('InstanceChargeType')
+
+	def set_InstanceChargeType(self, InstanceChargeType):  # String
+		self.add_query_param('InstanceChargeType', InstanceChargeType)
 	def get_AutoPay(self): # Boolean
 		return self.get_query_params().get('AutoPay')
 
 	def set_AutoPay(self, AutoPay):  # Boolean
 		self.add_query_param('AutoPay', AutoPay)
+	def get_DryRun(self): # Boolean
+		return self.get_query_params().get('DryRun')
+
+	def set_DryRun(self, DryRun):  # Boolean
+		self.add_query_param('DryRun', DryRun)
+	def get_PromotionOptionNo(self): # String
+		return self.get_query_params().get('PromotionOptionNo')
+
+	def set_PromotionOptionNo(self, PromotionOptionNo):  # String
+		self.add_query_param('PromotionOptionNo', PromotionOptionNo)
 	def get_BandwidthBillingType(self): # String
 		return self.get_query_params().get('BandwidthBillingType')
 
