@@ -66,11 +66,25 @@ class CreateBandwidthPackageRequest(RpcRequest):
 
 	def set_ResourceGroupId(self, ResourceGroupId):  # String
 		self.add_query_param('ResourceGroupId', ResourceGroupId)
+	def get_Tags(self): # RepeatList
+		return self.get_query_params().get('Tag')
+
+	def set_Tags(self, Tag):  # RepeatList
+		for depth1 in range(len(Tag)):
+			if Tag[depth1].get('Key') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tag[depth1].get('Key'))
+			if Tag[depth1].get('Value') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tag[depth1].get('Value'))
 	def get_AutoPay(self): # Boolean
 		return self.get_query_params().get('AutoPay')
 
 	def set_AutoPay(self, AutoPay):  # Boolean
 		self.add_query_param('AutoPay', AutoPay)
+	def get_PromotionOptionNo(self): # String
+		return self.get_query_params().get('PromotionOptionNo')
+
+	def set_PromotionOptionNo(self, PromotionOptionNo):  # String
+		self.add_query_param('PromotionOptionNo', PromotionOptionNo)
 	def get_Bandwidth(self): # Integer
 		return self.get_query_params().get('Bandwidth')
 
